==> luna_cow-0.6.81-py3-none-any.whl: cow/web/context.py <==
"""
Context for application.
Defines components and how do they depend on each other.
"""

import asyncio
from argparse import Namespace
from typing import Awaitable

from configs_core.base_service_setting import BaseServiceSettingsClass
from luna_plugins.base.manager import PluginManager

from ..metrics.entities import BaseMetricsContainer
from ..metrics.manager import LunaMetricsManager
from ..monitoring.manager import LunaMonitoringManager
from ..utils import mixins
from ..utils.log import logger


class LunaAppCtx[TConfig: BaseServiceSettingsClass]:
    """
    Base luna application context
    Attributes:
        cmdArgs: command line arguments
        logger: global app logger
        serviceConfig: service config
        pluginManager: plugin manager
        monitoring: service monitoring
        metrics: metrics manager
    """

    def __init__(self, config: TConfig, pluginManager: PluginManager | None = None):
        self.logger = logger
        self.serviceConfig = config
        self.monitoring = LunaMonitoringManager(settings=config.monitoring, pluginManager=pluginManager)
        self.metrics = LunaMetricsManager(
            settings=config.metrics, metricsContainer=BaseMetricsContainer(config.serviceName)
        )
        self.pluginManager = pluginManager
        self.cmdArgs: Namespace | None = None

    async def initialize(self):
        """
        Initialize service
        """
        coros = [x.initializeWrapper() for x in self if isinstance(x, mixins.Initializable)]

        await asyncio.gather(*coros)

    async def close(self):
        """
        Stop context. Make sure to close components in correct order.
        """
        # reverse so that components with dependencies will go first
        # doesn't guarantee safety
        for x in reversed(list(self)):
            if isinstance(x, mixins.Initializable):
                await x.close()

    def __iter__(self):
        """Yields class attributes for convenience."""
        yield from self.__dict__.values()

    def getChecks(self):
        """Returns coroutines to verify configuration."""
        checks = []
        for component in self:
            if hasattr(component, "probe"):
                checks.append(component.probe())

        return checks

    def getRuntimeChecks(self, includeLunaServices: bool) -> list[tuple[str, Awaitable]]:
        """Returns list of coroutines with codes that are used for /healthcheck resource."""
        checks = []
        for component in self:
            if hasattr(component, "getRuntimeChecks"):
                checks.extend(component.getRuntimeChecks(includeLunaServices))
        return checks

==> luna_cow-0.6.82-py3-none-any.whl: cow/web/context.py <==
"""
Context for application.
Defines components and how do they depend on each other.
"""

import asyncio
from argparse import Namespace
from typing import Awaitable

from configs_core.base_service_setting import BaseServiceSettingsClass
from luna_plugins.base.manager import PluginManager

from ..metrics.entities import BaseMetricsContainer
from ..metrics.manager import LunaMetricsManager
from ..monitoring.manager import LunaMonitoringManager
from ..utils import mixins
from ..utils.log import logger


class LunaAppCtx[TConfig: BaseServiceSettingsClass]:
    """
    Base luna application context
    Attributes:
        cmdArgs: command line arguments
        logger: global app logger
        serviceConfig: service config
        pluginManager: plugin manager
        monitoring: service monitoring
        metrics: metrics manager
    """

    def __init__(self, config: TConfig, pluginManager: PluginManager | None = None):
        self.logger = logger
        self.serviceConfig = config
        self.monitoring = LunaMonitoringManager(settings=config.monitoring, pluginManager=pluginManager)
        self.metrics = LunaMetricsManager(
            settings=config.metrics, metricsContainer=BaseMetricsContainer(serviceName=config.serviceName)
        )
        self.pluginManager = pluginManager
        self.cmdArgs: Namespace | None = None

    async def initialize(self):
        """
        Initialize service
        """
        coros = [x.initializeWrapper() for x in self if isinstance(x, mixins.Initializable)]

        await asyncio.gather(*coros)

    async def close(self):
        """
        Stop context. Make sure to close components in correct order.
        """
        # reverse so that components with dependencies will go first
        # doesn't guarantee safety
        for x in reversed(list(self)):
            if isinstance(x, mixins.Initializable):
                await x.close()

    def __iter__(self):
        """Yields class attributes for convenience."""
        yield from self.__dict__.values()

    def getChecks(self):
        """Returns coroutines to verify configuration."""
        checks = []
        for component in self:
            if hasattr(component, "probe"):
                checks.append(component.probe())

        return checks

    def getRuntimeChecks(self, includeLunaServices: bool) -> list[tuple[str, Awaitable]]:
        """Returns list of coroutines with codes that are used for /healthcheck resource."""
        checks = []
        for component in self:
            if hasattr(component, "getRuntimeChecks"):
                checks.extend(component.getRuntimeChecks(includeLunaServices))
        return checks
